@@ -1,4 +1,6 @@
 #define _XOPEN_SOURCE 600
+#include <unistd.h>
+#include <sys/types.h>
 #include <stdint.h>
 #include <fcntl.h>
 #include <stdlib.h>
@@ -19,7 +21,7 @@ static int epfd;
 int
 rawfalloc(int fd, int len)
 {
-    return posix_fallocate(fd, 0, len);
+    return ftruncate(fd, len);
 }
 
 
