@@ -48,8 +48,10 @@ make_server_socket(char *host, char *port)
     hints.ai_socktype = SOCK_STREAM;
     hints.ai_flags = AI_PASSIVE;
     r = getaddrinfo(host, port, &hints, &airoot);
-    if (r == -1)
-      return twarn("getaddrinfo()"), -1;
+    if (r != 0) {
+      twarnx("getaddrinfo(): %s", gai_strerror(r));
+      return -1;
+    }
 
     for(ai = airoot; ai; ai = ai->ai_next) {
       fd = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
@@ -98,28 +100,35 @@ make_server_socket(char *host, char *port)
         continue;
       }
 
-      if (verbose) {
-          char hbuf[NI_MAXHOST], pbuf[NI_MAXSERV], *h = host, *p = port;
-          r = getnameinfo(ai->ai_addr, ai->ai_addrlen,
-                  hbuf, sizeof hbuf,
-                  pbuf, sizeof pbuf,
-                  NI_NUMERICHOST|NI_NUMERICSERV);
-          if (!r) {
-              h = hbuf;
-              p = pbuf;
-          }
-          if (ai->ai_family == AF_INET6) {
-              printf("bind %d [%s]:%s\n", fd, h, p);
-          } else {
-              printf("bind %d %s:%s\n", fd, h, p);
-          }
-      }
       r = bind(fd, ai->ai_addr, ai->ai_addrlen);
       if (r == -1) {
         twarn("bind()");
         close(fd);
         continue;
       }
+      if (verbose) {
+          char hbuf[NI_MAXHOST], pbuf[NI_MAXSERV], *h = host, *p = port;
+         struct sockaddr_in addr;
+         socklen_t addrlen;
+
+         addrlen = sizeof(addr);
+         r = getsockname(fd, (struct sockaddr *) &addr, &addrlen);
+         if (!r) {
+             r = getnameinfo((struct sockaddr *) &addr, addrlen,
+                             hbuf, sizeof(hbuf),
+                             pbuf, sizeof(pbuf),
+                             NI_NUMERICHOST|NI_NUMERICSERV);
+             if (!r) {
+                 h = hbuf;
+                 p = pbuf;
+             }
+         }
+          if (ai->ai_family == AF_INET6) {
+              printf("bind %d [%s]:%s\n", fd, h, p);
+          } else {
+              printf("bind %d %s:%s\n", fd, h, p);
+          }
+      }
 
       r = listen(fd, 1024);
       if (r == -1) {
