@@ -1,11 +1,13 @@
 #include <stdlib.h>
 
+// prime // downscale treshold / upscale treshold
+
 size_t primes[] = {
-    12289,
-    24593,
-    49193,
-    98387,
-    196799,
+    12289, // NA / 3072
+    24593, // 1537 / 6148
+    49193, // 3074 / 12298
+    98387, // 6149 / 24596
+    196799, // etc
     393611,
     787243,
     1574491,
